@@ -10,7 +10,7 @@ configure and implement a workflow to operate on a signac_ data space.
 """
 from . import environment, errors, scheduling, testing
 from .environment import get_environment
-from .operations import cmd, directives, run, with_job
+from .operations import cmd, directives, with_job
 from .project import FlowProject, IgnoreConditions, classlabel, label, staticlabel
 from .template import init
 
@@ -35,7 +35,6 @@ __all__ = [
     "staticlabel",
     "cmd",
     "directives",
-    "run",
     "get_environment",
     "init",
     "redirect_log",
