@@ -334,7 +334,7 @@ def _is_fraction(value):
 
 
 def _parse_walltime(walltime):
-    """Parse walltime from the walltime flag passed by a user.
+    """Parse walltime from a walltime directive passed by a user.
 
     A valid walltime argument is defined as:
 
@@ -360,15 +360,17 @@ def _parse_walltime(walltime):
 
 
 def _parse_memory(memory):
-    """Parse memory from the memory flag passed by a user.
+    """Parse memory value from a memory directive passed by a user.
 
     A valid memory argument is defined as:
 
-    1. Numeric value with suffix "g" or "G" indicating memory requested in gigabytes.
-    2. Numeric value with suffix "m" or "M" indicating memory requested in megabytes.
+    1. Numeric value with suffix "G" or "GB" indicating memory requested in gigabytes.
+    2. Numeric value with suffix "M" or "MB" indicating memory requested in megabytes.
     3. Numeric value with no suffix indicating memory requested in gigabytes.
     4. None to indicate no specific memory request.
 
+    Memory arguments passed as strings are case insensitive.
+
     Parameters
     ----------
     memory : str or float or None
@@ -382,18 +384,19 @@ def _parse_memory(memory):
     try:
         if memory is None:
             return None
-        memory = str(memory)
+        # Convert to uppercase, remove "B" suffix if provided
+        memory = str(memory).upper().rstrip("B")
         size_type = memory[-1]
-        if size_type.lower() == "m":
+        if size_type == "M":
             return float(memory[:-1]) / 1024
-        elif size_type.lower() == "g":
+        elif size_type == "G":
             return float(memory[:-1])
         else:
             return float(memory)
     except ValueError:
         raise ValueError(
-            'Invalid memory passed. For gigabytes use suffix "g"/"G", '
-            'for megabytes use suffix "m"/"M". If a numeric value is passed then '
+            'Invalid memory passed. For gigabytes use suffix "G" or "GB", '
+            'for megabytes use suffix "M" or "MB". If a numeric value is passed then '
             "it will be interpreted as memory in gigabytes."
         )
 
@@ -430,6 +433,7 @@ def _sum_not_none(value, other):
         return operator.add(value, other)
 
 
+_bool = _OnlyTypes(bool)
 _natural_number = _OnlyTypes(int, postprocess=_raise_below(1))
 _nonnegative_int = _OnlyTypes(int, postprocess=_raise_below(0))
 _positive_real_walltime = _OnlyTypes(
@@ -451,10 +455,22 @@ _positive_real_memory = _OnlyTypes(
 
 
 # Common directives and their instantiation as _Directive
+_FORK = _Directive("fork", validator=_bool, default=False)
+_FORK.__doc__ = """The fork directive can be set to True to enforce that a
+particular operation is always executed within a subprocess and not within the
+Python interpreter's process even if there are no other reasons that would prevent that.
+
+.. note::
+
+    Setting ``fork=False`` will not prevent forking if there are other reasons for forking,
+    such as a timeout.
+"""
+
+
 _NP = _Directive(
     "np", validator=_natural_number, default=_NP_DEFAULT, finalize=_finalize_np
 )
-"""The number of tasks to launch for a given operation i.e., the number of CPU
+_NP.__doc__ = """The number of tasks to launch for a given operation i.e., the number of CPU
 cores to be requested for a given operation.
 
 Expects a natural number (i.e. an integer >= 1). This directive introspects into
@@ -463,19 +479,19 @@ greater than the current set value. Defaults to 1.
 """
 
 _NGPU = _Directive("ngpu", validator=_nonnegative_int, default=0)
-"""The number of GPUs to use for this operation.
+_NGPU.__doc__ = """The number of GPUs to use for this operation.
 
 Expects a nonnegative integer. Defaults to 0.
 """
 
 _NRANKS = _Directive("nranks", validator=_nonnegative_int, default=0)
-"""The number of MPI ranks to use for this operation. Defaults to 0.
+_NRANKS.__doc__ = """The number of MPI ranks to use for this operation. Defaults to 0.
 
 Expects a nonnegative integer.
 """
 
 _OMP_NUM_THREADS = _Directive("omp_num_threads", validator=_nonnegative_int, default=0)
-"""The number of OpenMP threads to use for this operation. Defaults to 0.
+_OMP_NUM_THREADS.__doc__ = """The number of OpenMP threads to use for this operation. Defaults to 0.
 
 Expects a nonnegative integer.
 """
@@ -487,7 +503,7 @@ _WALLTIME = _Directive(
     serial=_sum_not_none,
     parallel=_max_not_none,
 )
-"""The number of hours to request for executing this job.
+_WALLTIME.__doc__ = """The number of hours to request for executing this job.
 
 This directive expects a float representing the walltime in hours. Fractional
 values are supported. For example, a value of 0.5 will request 30 minutes of
@@ -514,12 +530,13 @@ _MEMORY = _Directive(
     serial=_max_not_none,
     parallel=_sum_not_none,
 )
-"""The memory to request for this operation.
+_MEMORY.__doc__ = """The memory to request for this operation.
 
 The memory to validate should be either a float, int, or string.
 A valid memory argument is defined as:
 
 - Positive numeric value with suffix "g" or "G" indicating memory requested in gigabytes.
+
 For example:
 
 .. code-block:: python
@@ -530,6 +547,7 @@ For example:
         pass
 
 - Positive numeric value with suffix "m" or "M" indicating memory requested in megabytes.
+
 For example:
 
 .. code-block:: python
@@ -540,6 +558,7 @@ For example:
         pass
 
 - Positive numeric value with no suffix indicating memory requested in gigabytes.
+
 For example:
 
 .. code-block:: python
@@ -562,7 +581,7 @@ _PROCESSOR_FRACTION = _Directive(
     serial=_no_aggregation,
     parallel=_no_aggregation,
 )
-"""Fraction of a resource to use on a single operation.
+_PROCESSOR_FRACTION.__doc__ = """Fraction of a resource to use on a single operation.
 
 If set to 0.5 for a bundled job with 20 operations (all with 'np' set to 1), 10
 CPUs will be used. Defaults to 1.
@@ -574,21 +593,22 @@ CPUs will be used. Defaults to 1.
 
 
 def _GET_EXECUTABLE():
-    """Return the path to the executable to be used for an operation.
-
-    The executable directive expects a string pointing to a valid executable
-    file in the current file system.
-
-    When called, by default this should point to a Python executable (interpreter);
-    however, if the :class:`FlowProject` path is an empty string, the executable
-    can be a path to an executable Python script. Defaults to ``sys.executable``.
-    """
-    # Evaluate the excutable directive at call-time instead of definition time.
+    # Evaluate the executable directive at call-time instead of definition time.
     # This is because we mock `sys.executable` while generating template reference data.
-    return _Directive(
+    _EXECUTABLE = _Directive(
         "executable",
         validator=_OnlyTypes(str),
         default=sys.executable,
         serial=_no_aggregation,
         parallel=_no_aggregation,
     )
+    _EXECUTABLE.__doc__ = """Return the path to the executable to be used for an operation.
+
+The executable directive expects a string pointing to a valid executable
+file in the current file system.
+
+When called, by default this should point to a Python executable (interpreter);
+however, if the :class:`FlowProject` path is an empty string, the executable
+can be a path to an executable Python script. Defaults to ``sys.executable``.
+"""
+    return _EXECUTABLE
