@@ -20,6 +20,7 @@ from deprecation import deprecated
 from signac.common import config
 
 from .directives import (
+    _FORK,
     _GET_EXECUTABLE,
     _MEMORY,
     _NGPU,
@@ -34,9 +35,9 @@ from .errors import NoSchedulerError
 from .scheduling.base import JobStatus
 from .scheduling.fake_scheduler import FakeScheduler
 from .scheduling.lsf import LSFScheduler
+from .scheduling.pbs import PBSScheduler
 from .scheduling.simple_scheduler import SimpleScheduler
 from .scheduling.slurm import SlurmScheduler
-from .scheduling.torque import TorqueScheduler
 from .util import config as flow_config
 from .version import __version__
 
@@ -225,12 +226,7 @@ class ComputeEnvironment(metaclass=_ComputeEnvironmentType):
             The argument parser where arguments will be added.
 
         """
-        parser.add_argument(
-            "-w",
-            "--walltime",
-            type=float,
-            help="The wallclock time in hours. Deprecated in 0.13 and will be removed in 0.14.",
-        )
+        pass
 
     @classmethod
     def get_config_value(cls, key, default=flow_config._GET_CONFIG_VALUE_NONE):
@@ -353,6 +349,7 @@ class ComputeEnvironment(metaclass=_ComputeEnvironmentType):
     def _get_default_directives(cls):
         return _Directives(
             [
+                _FORK,
                 _NP,
                 _NGPU,
                 _NRANKS,
@@ -396,27 +393,48 @@ class SimpleSchedulerEnvironment(ComputeEnvironment):
     template = "simple_scheduler.sh"
 
 
-class TorqueEnvironment(ComputeEnvironment):
-    """An environment with TORQUE scheduler."""
+@deprecated(
+    deprecated_in="0.14",
+    removed_in="0.15",
+    current_version=__version__,
+    details="PBSEnvironment has been deprecated, instead use DefaultPBSEnvironment",
+)
+class PBSEnvironment(ComputeEnvironment):
+    """An environment with PBS scheduler."""
 
-    scheduler_type = TorqueScheduler
-    template = "torque.sh"
+    pass
 
 
+@deprecated(
+    deprecated_in="0.14",
+    removed_in="0.15",
+    current_version=__version__,
+    details="SlurmEnvironment has been deprecated, instead use DefaultSlurmEnvironment",
+)
 class SlurmEnvironment(ComputeEnvironment):
     """An environment with SLURM scheduler."""
 
-    scheduler_type = SlurmScheduler
-    template = "slurm.sh"
+    pass
 
 
+@deprecated(
+    deprecated_in="0.14",
+    removed_in="0.15",
+    current_version=__version__,
+    details="LSFEnvironment has been deprecated, instead use DefaultLSFEnvironment",
+)
 class LSFEnvironment(ComputeEnvironment):
     """An environment with LSF scheduler."""
 
-    scheduler_type = LSFScheduler
-    template = "lsf.sh"
+    pass
 
 
+@deprecated(
+    deprecated_in="0.14",
+    removed_in="0.15",
+    current_version=__version__,
+    details="NodesEnvironment has been deprecated.",
+)
 class NodesEnvironment(ComputeEnvironment):
     """A compute environment consisting of multiple compute nodes.
 
@@ -424,9 +442,14 @@ class NodesEnvironment(ComputeEnvironment):
     e.g., CPUs.
     """
 
+    pass
 
-class DefaultTorqueEnvironment(NodesEnvironment, TorqueEnvironment):
-    """Default environment for clusters with a TORQUE scheduler."""
+
+class DefaultPBSEnvironment(ComputeEnvironment):
+    """Default environment for clusters with a PBS scheduler."""
+
+    scheduler_type = PBSScheduler
+    template = "pbs.sh"
 
     @classmethod
     def add_args(cls, parser):
@@ -455,9 +478,22 @@ class DefaultTorqueEnvironment(NodesEnvironment, TorqueEnvironment):
         )
 
 
-class DefaultSlurmEnvironment(NodesEnvironment, SlurmEnvironment):
+@deprecated(
+    deprecated_in="0.14",
+    removed_in="0.16",
+    current_version=__version__,
+    details="DefaultTorqueEnvironment has been renamed to DefaultPBSEnvironment",
+)
+class DefaultTorqueEnvironment(DefaultPBSEnvironment):  # noqa: D101
+    pass
+
+
+class DefaultSlurmEnvironment(ComputeEnvironment):
     """Default environment for clusters with a SLURM scheduler."""
 
+    scheduler_type = SlurmScheduler
+    template = "slurm.sh"
+
     @classmethod
     def add_args(cls, parser):
         """Add arguments to the parser.
@@ -480,9 +516,12 @@ class DefaultSlurmEnvironment(NodesEnvironment, SlurmEnvironment):
         )
 
 
-class DefaultLSFEnvironment(NodesEnvironment, LSFEnvironment):
+class DefaultLSFEnvironment(ComputeEnvironment):
     """Default environment for clusters with a LSF scheduler."""
 
+    scheduler_type = LSFScheduler
+    template = "lsf.sh"
+
     @classmethod
     def add_args(cls, parser):
         """Add arguments to the parser.
@@ -505,20 +544,6 @@ class DefaultLSFEnvironment(NodesEnvironment, LSFEnvironment):
         )
 
 
-@deprecated(deprecated_in="0.12", removed_in="0.14", current_version=__version__)
-class CPUEnvironment(ComputeEnvironment):
-    """An environment with CPUs."""
-
-    pass
-
-
-@deprecated(deprecated_in="0.12", removed_in="0.14", current_version=__version__)
-class GPUEnvironment(ComputeEnvironment):
-    """An environment with GPUs."""
-
-    pass
-
-
 def _import_configured_environments():
     cfg = config.load_config(config.FN_CONFIG)
     try:
