@@ -4,12 +4,12 @@
 #BSUB -J {{ id }}
 {% set memory_requested = operations | calc_memory(parallel) %}
 {% if memory_requested %}
-#BSUB -M {{ memory_requested }}GB
+#BSUB -M {{ memory_requested|format_memory }}B
 {% endif %}
 {% if partition %}
 #BSUB -q {{ partition }}
 {% endif %}
-{% set walltime = walltime | default(operations | calc_walltime(parallel), True) %}
+{% set walltime = operations | calc_walltime(parallel) %}
 {% if walltime %}
 #BSUB -W {{ walltime|format_timedelta(style='HH:MM') }}
 {% endif %}
