@@ -5,12 +5,12 @@
 #SBATCH --job-name="{{ id }}"
 {% set memory_requested = operations | calc_memory(parallel)  %}
 {% if memory_requested %}
-#SBATCH --mem={{ memory_requested }}G
+#SBATCH --mem={{ memory_requested|format_memory }}
 {% endif %}
 {% if partition %}
 #SBATCH --partition={{ partition }}
 {% endif %}
-{% set walltime = walltime | default(operations | calc_walltime(parallel), True) %}
+{% set walltime = operations | calc_walltime(parallel) %}
 {% if walltime %}
 #SBATCH -t {{ walltime|format_timedelta }}
 {% endif %}
